from django.utils.translation import ugettext as _
from samklang_menu.widgets import Widget
from samklang_payment.models import Donation, DonationCampaign
from django.db.models import Sum
from django.template.loader import render_to_string
from django.template.context import RequestContext

class DonationBox(Widget):
    """Lists out total donations and how to contribute."""

    def render(self, request):
        """Function to be called to be printed"""

        campaign_id = self.options.get("campaign")
        if campaign_id:
            campaign = DonationCampaign.objects.get(pk=campaign_id, payment_site=request.site)

            return render_to_string('samklang_payment/donation_box.html', {
                'amount': campaign.total_computed_donations,
                'currency': campaign.payment_site.default_currency,
                'slug': campaign.slug,
                'header': self.options.get("header"),
                'text': self.options.get("text"),

                }, context_instance=RequestContext(request))
        else:
            return ""

class Progress(Widget):
    """Show a progress bar of how we are doing against the target"""

    def render(self, request):
        """Function that is really called"""

        campaign_id = self.options.get("campaign")
        if campaign_id:
            campaign = DonationCampaign.objects.get(pk=campaign_id, payment_site=request.site)

            return render_to_string('samklang_payment/campaign_progress.html', {
            'progress': campaign.progress,
            })
        else:
            return ""



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):

        # Adding model 'Donation'
        db.create_table('samklang_payment_donation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('transaction', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=32, blank=True)),
            ('amount', self.gf('django.db.models.fields.DecimalField')(max_digits=7, decimal_places=2)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('captured', self.gf('django.db.models.fields.DateTimeField')(db_index=True, null=True, blank=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=80, blank=True)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75, blank=True)),
        ))
        db.send_create_signal('samklang_payment', ['Donation'])


    def backwards(self, orm):

        # Deleting model 'Donation'
        db.delete_table('samklang_payment_donation')


    models = {
        'samklang_payment.donation': {
            'Meta': {'object_name': 'Donation'},
            'amount': ('django.db.models.fields.DecimalField', [], {'max_digits': '7', 'decimal_places': '2'}),
            'captured': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '80', 'blank': 'True'}),
            'transaction': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '32', 'blank': 'True'})
        }
    }

    complete_apps = ['samklang_payment']



import floppyforms as forms

from samklang_utils.forms import MarkdownTextarea
from samklang_payment.models import Donation, DonationCampaign, PaymentSite

class DonationForm(forms.ModelForm):

    class Meta:
        model = Donation
        fields = ('amount', 'name', 'email')

class PaymentSiteUpdateForm(forms.ModelForm):

    class Meta:
        model = PaymentSite
        fields = ('merchant_id', 'test_key', 'production_key')

class DonationCampaignForm(forms.ModelForm):

    class Meta:
        model = DonationCampaign
        fields = ('name', 'description', 'test_mode', 'started', 'target_amount', 'total_donations', 'other_donations', 'thank_you_text')
        widgets = {'thank_you_text': MarkdownTextarea()}



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'DonationCampaign'
        db.create_table('samklang_payment_donationcampaign', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('payment_site', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['samklang_payment.PaymentSite'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=80)),
            ('slug', self.gf('django.db.models.fields.SlugField')(max_length=50, db_index=True)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True)),
            ('test_mode', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('target_amount', self.gf('django.db.models.fields.DecimalField')(null=True, max_digits=9, decimal_places=2, blank=True)),
            ('total_donations', self.gf('django.db.models.fields.DecimalField')(null=True, max_digits=9, decimal_places=2, blank=True)),
            ('other_donations', self.gf('django.db.models.fields.DecimalField')(null=True, max_digits=9, decimal_places=2, blank=True)),
            ('thank_you_text', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('thank_you_text_html', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('created', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('started', self.gf('django.db.models.fields.DateTimeField')()),
            ('updated', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal('samklang_payment', ['DonationCampaign'])

        # Adding model 'PaymentSite'
        db.create_table('samklang_payment_paymentsite', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('site', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['sites.Site'], unique=True)),
            ('default_currency', self.gf('django.db.models.fields.CharField')(default='NOK', max_length=3)),
            ('merchant_id', self.gf('django.db.models.fields.CharField')(max_length=32, blank=True)),
            ('test_key', self.gf('django.db.models.fields.CharField')(max_length=32, blank=True)),
            ('production_key', self.gf('django.db.models.fields.CharField')(max_length=32, blank=True)),
        ))
        db.send_create_signal('samklang_payment', ['PaymentSite'])

        # Adding field 'Donation.campaign'
        db.add_column('samklang_payment_donation', 'campaign', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['samklang_payment.DonationCampaign'], null=True, blank=True), keep_default=False)


    def backwards(self, orm):
        
        # Deleting model 'DonationCampaign'
        db.delete_table('samklang_payment_donationcampaign')

        # Deleting model 'PaymentSite'
        db.delete_table('samklang_payment_paymentsite')

        # Deleting field 'Donation.campaign'
        db.delete_column('samklang_payment_donation', 'campaign_id')


    models = {
        'samklang_payment.donation': {
            'Meta': {'ordering': "('-created',)", 'object_name': 'Donation'},
            'amount': ('django.db.models.fields.DecimalField', [], {'max_digits': '7', 'decimal_places': '2'}),
            'campaign': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['samklang_payment.DonationCampaign']", 'null': 'True', 'blank': 'True'}),
            'captured': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '80', 'blank': 'True'}),
            'transaction': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '32', 'blank': 'True'})
        },
        'samklang_payment.donationcampaign': {
            'Meta': {'object_name': 'DonationCampaign'},
            'created': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '80'}),
            'other_donations': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '2', 'blank': 'True'}),
            'payment_site': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['samklang_payment.PaymentSite']"}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'db_index': 'True'}),
            'started': ('django.db.models.fields.DateTimeField', [], {}),
            'target_amount': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '2', 'blank': 'True'}),
            'test_mode': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'thank_you_text': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'thank_you_text_html': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'total_donations': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '2', 'blank': 'True'}),
            'updated': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        },
        'samklang_payment.paymentsite': {
            'Meta': {'object_name': 'PaymentSite'},
            'default_currency': ('django.db.models.fields.CharField', [], {'default': "'NOK'", 'max_length': '3'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'merchant_id': ('django.db.models.fields.CharField', [], {'max_length': '32', 'blank': 'True'}),
            'production_key': ('django.db.models.fields.CharField', [], {'max_length': '32', 'blank': 'True'}),
            'site': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['sites.Site']", 'unique': 'True'}),
            'test_key': ('django.db.models.fields.CharField', [], {'max_length': '32', 'blank': 'True'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['samklang_payment']



from django.test import TestCase
from datetime import datetime
from pytz import utc
from samklang_payment.views import get_transaction_id, get_execution_time

class TestDonation(TestCase):


    def test_get_transaction_id(self):
        """
        From register response, get the transaction id
        """

        example_response = """<?xml version="1.0"?>
<RegisterResponse xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema">
  <TransactionId>6d16d881b9d1497a8b9bae21eaf7e760</TransactionId>
</RegisterResponse>"""

        transaction_id = get_transaction_id(example_response)
        self.assertEqual(u"6d16d881b9d1497a8b9bae21eaf7e760", transaction_id)

    def test_get_execution_time(self):

        example_response = """<?xml version="1.0" ?>
<ProcessResponse xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema">
    <Operation>AUTH</Operation>
    <ResponseCode>OK</ResponseCode>
   <AuthorizationId>064392</AuthorizationId>
   <TransactionId>b127f98b77f741fca6bb49981ee6e846</TransactionId>
   <ExecutionTime>2009-12-16T11:17:54.633125+01:00</ExecutionTime>
   <MerchantId>9999997</MerchantId>
</ProcessResponse>"""

        correct_datetime = datetime(2009, 12, 16, 10, 17, 54, 633125, utc)
        execution_time = get_execution_time(example_response)
        self.assertEqual(correct_datetime, execution_time)



from urllib2 import urlopen
from urllib import quote
from BeautifulSoup import BeautifulSoup
from django.core.urlresolvers import reverse
from django.shortcuts import render_to_response
from django.template.context import RequestContext
from django.http import HttpResponseRedirect
from django.views.generic import CreateView, UpdateView, ListView, DetailView
from samklang_payment.models import Donation, PaymentSite, DonationCampaign
from samklang_payment.forms import DonationForm, PaymentSiteUpdateForm, DonationCampaignForm
from pyrfc3339 import parse
from django.utils.translation import ugettext as _
from django.contrib.auth.decorators import login_required
from django.utils.decorators import method_decorator

NETS_TEST_HOST = "epayment-test.bbs.no"
NETS_PRODUCTION_HOST = "epayment.bbs.no"

class DonationDetailView(DetailView):
    model = Donation
    slug_field = 'transaction'

class DonationCreateView(CreateView):
    model = Donation
    form_class = DonationForm

    def form_valid(self, form):
        """We get back form data, save the object, and initiates payment at Nets"""

        # save here to get id
        donation = form.save(commit=False)
        donation.campaign = DonationCampaign.objects.get(slug=self.kwargs.get('slug'), payment_site=self.request.site.paymentsite)
        redirect_url = "http://"+self.request.get_host()+reverse('payment-donation-create', kwargs={'slug': donation.campaign.slug})
        configuration = donation.campaign.payment_site
        if not configuration:
            return render_to_response('samklang_payment/error.html',
                        {'error': _('Payment site authentication is not yet set up.')},
                        context_instance=RequestContext(self.request))
        donation.save()
        if donation.campaign.test_mode:
            nets_host = NETS_TEST_HOST
            token = configuration.test_key
        else:
            nets_host = NETS_PRODUCTION_HOST
            token = configuration.production_key

        url = "https://%(nets_host)s/Netaxept/Register.aspx?merchantId=%(merchant_id)s&token=%(token)s&orderNumber=%(order_number)d&amount=%(amount)d&currencyCode=%(currency_code)s&redirecturl=%(redirect_url)s" % {
                'nets_host': nets_host,
                'amount': int(donation.amount*100),
                'merchant_id': configuration.merchant_id, #settings.NETS_MERCHANT_ID,
                'order_number': donation.id,
                'token': quote(token),
                'currency_code': configuration.default_currency.upper(),
                'redirect_url': redirect_url,
                }

        response = urlopen(url)
        data = response.read()
        try:
            transaction_id = get_transaction_id(data)
        except ValueError, e:
            return render_to_response('samklang_payment/error.html',
                    {'error': e},
                    context_instance=RequestContext(self.request))

        #if no error, redirect user to online payment terminal
        donation.transaction = transaction_id
        donation.save()
        url = "https://%(nets_host)s/Terminal/default.aspx?merchantid=%(merchant_id)s&transactionid=%(transaction_id)s" % {
                'nets_host': nets_host,
                'transaction_id': transaction_id,
                'merchant_id': configuration.merchant_id,
                }
        return HttpResponseRedirect(url)


    def get(self, request, *args, **kwargs):
        campaign = DonationCampaign.objects.get(slug=self.kwargs.get('slug'), payment_site=self.request.site.paymentsite)
        configuration = campaign.payment_site
        if not configuration:
            return render_to_response('samklang_payment/error.html',
                        {'error': _('Payment site authentication is not yet set up.')},
                        context_instance=RequestContext(self.request))
        if campaign.test_mode:
            nets_host = NETS_TEST_HOST
            token = configuration.test_key
        else:
            nets_host = NETS_PRODUCTION_HOST
            token = configuration.production_key

        if 'transactionId' in request.GET:
            # Last step: run transaction and get status from nets
            transaction_id = request.GET.get('transactionId', None)
            if not transaction_id:
                return render_to_response('samklang_payment/error.html',
                        {'error': _('Transaction ID was empty')},
                        context_instance=RequestContext(request))

            url = "https://%(nets_host)s/Netaxept/Process.aspx?merchantId=%(merchant_id)s&token=%(token)s&transactionId=%(transaction_id)s&operation=SALE" % {
                    'nets_host': nets_host,
                    'transaction_id': transaction_id,
                    'merchant_id': configuration.merchant_id,
                    'token': quote(token),
                    }
            response = urlopen(url)
            data = response.read()
            try:
                response_code = get_response_code(data)
                execution_time = get_execution_time(data)
            except ValueError, e:
                return render_to_response('samklang_payment/error.html',
                        {'error': e},
                        context_instance=RequestContext(request))

            if response_code == "OK":
                donation = Donation.objects.get(transaction=transaction_id)
                donation.captured = execution_time
                donation.save()
                return HttpResponseRedirect(reverse('payment-donation-detail', kwargs={'campaign_slug': donation.campaign.slug, 'slug': transaction_id}))
            else:
                return render_to_response('samklang_payment/error.html',
                        {'error': "%s: %s" % (response_code, handle_error(data))},
                        context_instance=RequestContext(request))
        else:
            return super(DonationCreateView, self).get(request, *args, **kwargs)


def handle_error(text):
    soup = BeautifulSoup(text)
    message_tag = soup.find("message")
    if not message_tag:
        return "Unknown error"
    else:
        return message_tag.text

def get_transaction_id(text):
    soup = BeautifulSoup(text)
    transaction_id_tag = soup.find("transactionid")
    if not transaction_id_tag:
        error = handle_error(text)
        raise ValueError(error)
    else:
        return transaction_id_tag.text

def get_response_code(text):
    soup = BeautifulSoup(text)
    response_code = soup.find("responsecode")
    if not response_code:
        error = handle_error(text)
        raise ValueError(error)
    else:
        return response_code.text

def get_execution_time(text):
    soup = BeautifulSoup(text)
    execution_time = soup.find("executiontime")
    if not execution_time:
        error = handle_error(text)
        raise ValueError(error)
    else:
        return parse(execution_time.text)

class PaymentSiteDetailView(DetailView):
    model = PaymentSite

    def get_object(self):
        return self.request.site.paymentsite

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(PaymentSiteDetailView, self).dispatch(*args, **kwargs)

class PaymentSiteUpdateView(UpdateView):
    model = PaymentSite
    form_class = PaymentSiteUpdateForm

    def get_object(self):
        return self.request.site.paymentsite

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(PaymentSiteUpdateView, self).dispatch(*args, **kwargs)

class DonationCampaignListView(ListView):
    model = DonationCampaign

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(DonationCampaignListView, self).dispatch(*args, **kwargs)

class DonationCampaignDetailView(DetailView):
    model = DonationCampaign

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(DonationCampaignDetailView, self).dispatch(*args, **kwargs)

class DonationCampaignUpdateView(UpdateView):
    model = DonationCampaign
    form_class = DonationCampaignForm

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(DonationCampaignUpdateView, self).dispatch(*args, **kwargs)




from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.sites.models import Site
from django.db.models import Sum
#from stdimage import StdImageField

class PaymentSite(models.Model):
    site = models.OneToOneField(Site, verbose_name=_('site'))
    default_currency = models.CharField(_('default currency'), max_length=3, default="NOK")
    merchant_id = models.CharField(_('merchant id'), max_length=32, blank=True)
    test_key = models.CharField(_('test key'), max_length=32, blank=True)
    production_key = models.CharField(_('production key'), max_length=32, blank=True)

    def __unicode__(self):
        return self.site.name

    @models.permalink
    def get_absolute_url(self):
        return ('payment-site-detail',)

    class Meta:
        verbose_name, verbose_name_plural = _('site'), _('sites')


class DonationCampaign(models.Model):
    payment_site = models.ForeignKey(PaymentSite, verbose_name=_('payment site'))
    name = models.CharField(_('name'), max_length=80)
    slug = models.SlugField(_('slug'))
    description = models.CharField(_('description'), max_length=250, blank=True)
    test_mode = models.BooleanField(_('test mode'), default=True, help_text=_("Run this campaign in test mode, not transfering real money."))
    target_amount = models.DecimalField(_('target amount'), max_digits=9, decimal_places=2, blank=True, null=True)
    total_donations = models.DecimalField(_('total donations'), max_digits=9, decimal_places=2, help_text=_('The total amount of donations to this campaign. Fill in this value OR "other donations".'), blank=True, null=True)
    other_donations = models.DecimalField(_('other donations'), max_digits=9, decimal_places=2, help_text=_('Donations made elsewhere to the system. If this is used, the total will be updated automatically.'), blank=True, null=True)
    # next line or special page with info about the transaction?
    #thank_you_page_url = models.CharField(_('thank you page url'), max_length=100, help_text=_("Redirect to this page to thank the users for their contributions"))
    thank_you_text = models.TextField(_('thank you text'), blank=True)
    thank_you_text_html = models.TextField(null=True, blank=True)
    created = models.DateTimeField(_('created'), auto_now_add=True)
    started = models.DateTimeField(_('started'), help_text=('Official start date'))
    updated = models.DateTimeField(_('updated'), auto_now=True)

    def __unicode__(self):
        return self.name

    @models.permalink
    def get_absolute_url(self):
        return ('payment-campaign-detail', [self.slug])

    class Meta:
        verbose_name, verbose_name_plural = _('campaign'), _('campaigns')

    @property
    def online_donations(self):
        return self.donation_set.filter(captured__isnull=False).aggregate(Sum('amount'))['amount__sum']

    @property
    def total_computed_donations(self):
        if self.other_donations:
            return self.other_donations + self.online_donations
        else:
            return self.total_donations

    @property
    def other_computed_donations(self):
        if self.other_donations:
            return self.other_donations
        else:
            return self.total_donations - self.online_donations

    @property
    def progress(self):
        return "%.1f" % (self.total_computed_donations *100 / self.target_amount)


class DonationManager(models.Manager):

    #def get_query_set(self):
    #    return super(CapturedManager, self).get_query_set().filter(captured__isnull=False)

    def captured(self):
        return self.get_query_set().filter(captured__isnull=False)

class Donation(models.Model):
    # nets' "order id" is model id
    campaign = models.ForeignKey(DonationCampaign, verbose_name=('campaign'), null=True, blank=True)
    transaction = models.CharField(_('transaction'), max_length=32, blank=True, db_index=True, help_text=_('transaction reference from nets'))
    amount = models.DecimalField(_('amount'), max_digits=7, decimal_places=2)
    created = models.DateTimeField(_('created'), auto_now_add=True)
    captured = models.DateTimeField(_('captured'), blank=True, null=True, db_index=True)
    name = models.CharField(_('name'), max_length=80, blank=True, help_text=_('Optional. Put your name here if you want this to be linked to your name later.'))
    email = models.EmailField(_('email'), max_length=75, blank=True, help_text=_('Optional. In the future, we would like to send announcements to our contributors.'))

    # managers
    objects = DonationManager()
    #captured_transactions = CapturedManager()

    def __unicode__(self):
        return u"%s %s" % (self.created.strftime("%Y-%m-%d %H:%M:%S"), self.amount)

    class Meta:
        ordering = ("-created",)
        verbose_name, verbose_name_plural = _('donation'), _('donations')



from django.conf.urls.defaults import *
from samklang_payment.views import *

urlpatterns = patterns('',
        url(r'^campaign/$', DonationCampaignListView.as_view(), name='payment-campaign-list'),
        url(r'^campaign/(?P<slug>[-\w]+)/$', DonationCampaignDetailView.as_view(), name='payment-campaign-detail'),
        url(r'^campaign/(?P<slug>[-\w]+)/edit/$', DonationCampaignUpdateView.as_view(), name='payment-campaign-update'),
        url(r'^campaign/(?P<slug>[-\w]+)/donate/$', DonationCreateView.as_view(), name='payment-donation-create'),
        url(r'^campaign/(?P<campaign_slug>[-\w]+)/donated/(?P<slug>[-\w]+)/$', DonationDetailView.as_view(), name='payment-donation-detail'),
        url(r'^update/$', PaymentSiteUpdateView.as_view(), name='payment-site-update'),
        url(r'^configuration/$', PaymentSiteDetailView.as_view(), name='payment-site-detail'),
        )



from django.contrib import admin
from samklang_payment.models import Donation, DonationCampaign, PaymentSite

# will work when 1.4 is out
#class CapturedStatusfilter(SimpleListFilter):

    #title = _('Transaction status')
    #parameter_name = 'captured'

    #def lookups(self, request, model_admin):
        #return (
                #(True, _('Verified transactions')),
                #(False, _('Failed transactions')),
                #)

    #def queryset(self, request, queryset):
        #if self.value == True:
            #queryset.exclude(captured__isnull=True)
        #else:
            #queryset.exclude(captured__isnull=False)

class DonationAdmin(admin.ModelAdmin):
    list_display = ('campaign', 'created', 'captured', 'amount')
    list_filter = ('campaign', 'captured',)
    #list_filter = (CapturedStatusfilter,)


admin.site.register(Donation, DonationAdmin)
admin.site.register(PaymentSite)
admin.site.register(DonationCampaign)



#!/usr/bin/env python
from distutils.core import setup

setup(
        name='samklang-payment',
        version="0.3.0",
        author='Sigurd Gartmann',
        author_email='sigurdga-samklang@sigurdga.no',
        url='http://github.com/sigurdga/samklang-payment',
        description='Donations and payment app for Samklang',
        long_description=open('README.txt').read(),
        license="AGPL",
        packages = ['samklang_payment', 'samklang_payment.migrations'],
        package_data = {'samklang_payment': ['templates/samklang_payment/*.html', 'locale/*/LC_MESSAGES/django.*o']},
        install_requires=['pytz>=2011n','pyRFC3339>=0.1'],
        classifiers=[
                "Development Status :: 3 - Alpha",
                "License :: OSI Approved :: GNU Affero General Public License v3",
                "Intended Audience :: Developers",
                "Framework :: Django",
                "Environment :: Web Environment",
                "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
                ]
        )
